==> OpenOLAP_V1.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/DimensionMemberDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFDimensionMemberDAO.java
 *  FfBVo[IuWFNg̉iǗC^[tF[XłB
 *
 *  쐬: 2004/01/09
 */
package openolap.viewer.dao;

import java.io.PrintWriter;
import java.sql.SQLException;
import java.util.ArrayList;

import openolap.viewer.Axis;
import openolap.viewer.Dimension;
import openolap.viewer.DimensionMember;
import openolap.viewer.Report;

/**
 *  C^[tF[XFDimensionMemberDAO
 *  FfBVo[IuWFNg̉iǗC^[tF[XłB
 */
public interface DimensionMemberDAO {

	/**
	 * |[gS̃oID̏ŏo
	 * @param report |[gIuWFNg
	 * @param out PrintWriterIuWFNg
	 * @exception SQLException ɗO
	 */
	public void outputDimensionMemberAsXML(Report report, PrintWriter out) throws SQLException;

	/**
	 * w肳ꂽ̃oo
	 * @param report |[gIuWFNg
	 * @param axis IuWFNg
	 * @param selectFLG ̃o[i荞܂Ă邩ǂ킷tO
	 * @param out PrintWriterIuWFNg
	 * @exception SQLException ɗO
	 */
	public void outputDimensionMemberAsXML(Report report, Axis axis, boolean selectFLG, PrintWriter out) throws SQLException;

	/**
	 * w肳ꂽfBṼo[IuWFNg̃Xg߂B
	 * @param dim fBVIuWFNg
	 * @param shortNameCondition V[gl[ɂ擾
	 * @param longNameCondition Ol[ɂ擾
	 * @param levelCondition xɂ擾
	 * @param selectedKeyString 擾ΏۂƂ郁o[L[̃Xg킷
	 * @return fBVo[IuWFNg̃Xg
	 * @exception SQLException ɗO
	 */
	public ArrayList selectDimensionMembers(Dimension dim, String shortNameCondition, String longNameCondition, String levelCondition, String selectedKeyString) throws SQLException;

	/**
	 * fBVIuWFNg̃o[\^CvAXML̃^OɕϊB
	 * @param modelString o[\^Cv킷
	 * @return XML̃^O
	 */
	public String transferMemberDisplayTypeFromModelToXML(String string);

	/**
	 * ^ꂽfBVo[߂B
	 * @param dim fBVIuWFNg
	 * @return o[
	 * @exception SQLException ɗO
	 */
	public int getDimensionMemberNumber(Dimension dim) throws SQLException;

	/**
	 * w肳ꂽfBṼo[IuWFNgXg̐擪̃o[IuWFNg߂B
	 * @param dim fBVIuWFNg
	 * @return fBVo[IuWFNg
	 * @exception SQLException ɗO
	 */
	public DimensionMember getFirstMember(Dimension dim) throws SQLException;
}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/DimensionMemberDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFDimensionMemberDAO.java
 *  FfBVo[IuWFNg̉iǗC^[tF[XłB
 *
 *  쐬: 2004/01/09
 */
package openolap.viewer.dao;

import java.io.PrintWriter;
import java.sql.SQLException;
import java.util.ArrayList;

import openolap.viewer.Axis;
import openolap.viewer.Dimension;
import openolap.viewer.DimensionMember;
import openolap.viewer.Report;

/**
 *  C^[tF[XFDimensionMemberDAO<br>
 *  FfBVo[IuWFNg̉iǗC^[tF[XłB
 */
public interface DimensionMemberDAO {

	/**
	 * |[gS̃oID̏ŏo
	 * @param report |[gIuWFNg
	 * @param out PrintWriterIuWFNg
	 * @exception SQLException ɗO
	 */
	public void outputDimensionMemberAsXML(Report report, PrintWriter out) throws SQLException;

	/**
	 * w肳ꂽ̃oo
	 * @param report |[gIuWFNg
	 * @param axis IuWFNg
	 * @param selectFLG ̃o[i荞܂Ă邩ǂ킷tO
	 * @param out PrintWriterIuWFNg
	 * @exception SQLException ɗO
	 */
	public void outputDimensionMemberAsXML(Report report, Axis axis, boolean selectFLG, PrintWriter out) throws SQLException;

	/**
	 * w肳ꂽfBṼo[IuWFNg̃Xg߂B
	 * @param dim fBVIuWFNg
	 * @param shortNameCondition V[gl[ɂ擾
	 * @param longNameCondition Ol[ɂ擾
	 * @param levelCondition xɂ擾
	 * @param selectedKeyString 擾ΏۂƂ郁o[L[̃Xg킷
	 * @return fBVo[IuWFNg̃Xg
	 * @exception SQLException ɗO
	 */
	public ArrayList selectDimensionMembers(Dimension dim, String shortNameCondition, String longNameCondition, String levelCondition, String selectedKeyString) throws SQLException;

	/**
	 * fBVIuWFNg̃o[\^CvAXML̃^OɕϊB
	 * @param modelString o[\^Cv킷
	 * @return XML̃^O
	 */
	public String transferMemberDisplayTypeFromModelToXML(String string);

	/**
	 * ^ꂽfBVo[߂B
	 * @param dim fBVIuWFNg
	 * @return o[
	 * @exception SQLException ɗO
	 */
	public int getDimensionMemberNumber(Dimension dim) throws SQLException;

	/**
	 * w肳ꂽfBṼo[IuWFNgXg̐擪̃o[IuWFNg߂B
	 * @param dim fBVIuWFNg
	 * @return fBVo[IuWFNg
	 * @exception SQLException ɗO
	 */
	public DimensionMember getFirstMember(Dimension dim) throws SQLException;
}
